"""
.. autosummary::
   :toctree:

    react

"""

from .setup_info import SETUP_INFO

__version__ = SETUP_INFO['version']

# intersphinx_urls = dict(docs="http://react.lino-framework.org")
srcref_url = 'https://github.com/lino-framework/react/blob/master/%s'
doc_trees = ['docs']
intersphinx_urls = dict(docs="https://react.lino-framework.org")
